#!/usr/bin/perl
#
# Small Makefile to cat the needed sub_routines from ./src/
#
# Tue Jan 15 20:13:39 CET 2002 Martin J. Muench (mjm@remote-exploit.org)

# Oh yeah, be hard, be tough, just be #
use strict;

# Define needed variables #
my $source;
my @make;
my $i=0;

# OS Detection #

if ($^O =~ m/bsd/) { 

  # open(BSD), sometimes called OpenBSD by some kiddies ;-P
  open(BSD, '<src/bsd.h') || die "Cannot open bsd.h: $!\n";

  while(<BSD>) {
	chomp($_);
	$make[$i++]=$_;
  }
  close(BSD);
}

elsif ($^O =~ m/linux/) { 

  # open(Linux)
  open(LINUX, '<src/linux.h') || die "Cannot open linux.h: $!\n";

  while(<LINUX>) {
        chomp($_);
        $make[$i++]=$_;
  }
  close(LINUX);
}

else { print "OS unknown, mail author\n\n"; exit; }

# Open Outputfile and say hello #
open(WELLENREITER, '>Wellenreiter.pl') || die "Cannot open Outputfile: $!\n";
#print "\nBuilding Wellenreiter for $^O\n\n";

# Cat content of every needed file into Outputfile #
foreach $source (@make) {

	#print "Including file: $source\n";

	open(TEMP, "src/$source") || die "Cannot open Tempfile: $!\n";
	while(<TEMP>) { print WELLENREITER $_; } 
	close(TEMP);

}

# Say Good-bye #
#print "\nSuccessfully build 'Wellenreiter.pl'\n\n";
close(WELLENREITER);


# Build the config-file '~/.wellenreiter.rc'


## Location of the configfile

my $conffile=%ENV->{HOME}."/.wellenreiter.rc";

## Function prototyping

sub bsd_conf;
sub linux_conf;
sub common;

##-- Begin of Main --##

## Welcome screen
print "\n************************************************************";
print "\n*                                                          *";
print "\n* Wellenreiter config generator by team remote-exploit.org *";
print "\n*                                                          *";
print "\n*             http://www.remote-exploit.org                *";
print "\n*                                                          *";
print "\n************************************************************";
print "\n\n              Press the return to continue "; sleep until <STDIN>;

## Create configfile

open(CONF, ">$conffile") || die "Error while opening config-file: $!";
print CONF "#############################################################\n";
print CONF "#                                                           #\n";
print CONF "#          This is the config file of Wellenreiter          #\n";
print CONF "#  It has been automaticly created using perl Makefile.pl   #\n";
print CONF "# Please do not modify this file, if you dont know what you #\n";
print CONF "# are doing! If you simply want to change the cardtype etc, #\n";
print CONF "# re-run perl Makefile.pl from the Wellenreiter source dir. #\n";
print CONF "#                                                           #\n";
print CONF "#############################################################\n";
print CONF "# Team remote-exploit.org:                                  #\n";
print CONF "#                          http://www.remote-exploit.org    #\n";
print CONF "#############################################################\n\n";

if ($^O =~ m/bsd/) { 
	print "You are using BSD, if not please abort and drop us a mail\n\n";
	bsd_conf;
}

elsif ($^O =~ m/linux/) {
	print "\nYou are using Linux, if not please abort and drop us a mail\n\n";
	linux_conf;
}

else { print "Unknown OS, try to build your config-file manually\n"; }

## Add the common stuff to configfile
common;

## Everythings done
close(CONF); exit(1);

##-- End of Main --##

## BSD_Conf
sub bsd_conf {

## We use BSD, yeah

# Get the interface
  print "Set your wireless interface [default: wi0] : ";
  chomp(my $device=<STDIN>);
  if(!$device) { print CONF "interface=wi0\n"; }
  else { print CONF "interface=$device\n"; }

# Get the path to wicontrol
  print "Set path to wicontrol [default: /usr/sbin/wicontrol] : ";
  chomp(my $path=<STDIN>);
  if(!$path) { print CONF "wicontrol=/usr/sbin/wicontrol\n"; }
  else { print CONF "wicontrol=$path\n"; }

# Fix the buttons
  print CONF "mwbuttons=Linkquality,Signallevel,Noiselevel,MISC-Stats,Card-Config,About\n";

# Enough for now, the rest is done by hand
  print "For more options, look at ~/.wellenreiter.rc\n\n";
  print "All necessary things are now configured\n\n";

}

## Linux_Conf

sub linux_conf 
{

## Well, lets use linux

# Get the card type for iface1
  print "\nChoose your wireless card type [cisco|prism2|lucent] [default: cisco] : ";
  chomp(my $devtyp=<STDIN>);
  my $buttonstobuild;
  if(!$devtyp || $devtyp eq 'cisco') 
  {
  	print CONF "iface1typ=cisco\n";
	  print "\nSet your wireless interface name [default: eth1] : ";
	  chomp(my $device=<STDIN>);
	  if(!$device) { print CONF "interface=eth1\n"; }
	  else { print CONF "interface=$device\n"; }
	 # print CONF "mwbuttons_cisco=Linkquality,Signallevel,RX-Stats,TX-Stats,MISC-Stats,Card-Config,Scanner,Batterymon,Log,About\n";
	 $buttonstobuild='Linkquality,Signallevel,RX-Stats,TX-Stats,MISC-Stats,Card-Config,Scanner,Batterymon,Log,About';
  }
  elsif ($devtyp eq 'prism2')
  {
  	print CONF "iface1typ=prism2\n";
	  print "\nSet your wireless interface name [default: wlan0] : ";
	  chomp(my $device=<STDIN>);
	  if(!$device) { print CONF "interface=wlan0\n"; }
	  else { print CONF "interface=$device\n"; }
  	$buttonstobuild='RX-Stats,TX-Stats,MISC-Stats,Card-Config,Scanner,Batterymon,Log,About';
  }
    elsif ($devtyp eq 'lucent')
  {
  	print CONF "iface1typ=lucent\n";
	  print "\nSet your wireless interface name [default: eth1] : ";
	  chomp(my $device=<STDIN>);
	  if(!$device) { print CONF "interface=eth1\n"; }
	  else { print CONF "interface=$device\n"; }
#  	print CONF "mwbuttons=Linkquality,Signallevel,Noiselevel,RX-Stats,TX-Stats,MISC-Stats,Card-Config,Scanner,Batterymon,Log,About\n";
  	$buttonstobuild='Linkquality,Signallevel,Noiselevel,RX-Stats,TX-Stats,MISC-Stats,Card-Config,Scanner,Batterymon,Log,About';

  }
  else
  {
  	print "\nSorry you entered something strange...please enter either \"cisco\" or \"prism2\" or \"lucent\"";
  	print "\nThe program cannot continue.....aborting...";
  	exit;
  }

# Got compatible sniffing card ?
  print "\nDo u got a RAW-capture rfmon compatible card (read README) ? [y/n] [default: n] : ";
  chomp(my $got_raw_card=<STDIN>);
  if(!$got_raw_card || $got_raw_card eq 'n')
  { 
  	print CONF "got_raw_card=n\n"; 
  	$buttonstobuild =~ s/Scanner,//;
  }
  else 
  { 
  	print CONF "got_raw_card=y\n"; 
  	# Get the card type for iface2
	   print "\nChoose your type for this card [cisco|prism2|lucent] [default: cisco] : ";
	   chomp(my $dev2typ=<STDIN>);
   	if(!$dev2typ || $dev2typ eq 'cisco') 
  		{
			  print "\nSet your wireless interface name [default: eth2] : ";
	 		 chomp(my $sniffer_device=<STDIN>);
  			if(!$sniffer_device) 
  			{ 
  				print CONF "sniffer_device=eth2\n";
  			}
  			else 
  			{   print CONF "sniffer_device=$sniffer_device\n";
	  		}

  			#-- Write type to conf --#
  				print CONF "iface2typ=cisco\n";
  			#-- Write the default settings for bring cisco cards in sniffing mode --#
        	  	# Command to bring $sniffer_device into rfmon mode
  					print CONF 'start_sniff_command=' . 'echo "Mode: r" > /proc/driver/aironet/%sniffer_device%/Config && echo "Mode: y" > /proc/driver/aironet/%sniffer_device%/Config'."\n";
		   	   # Command to stop $sniffer_device from rfmon mode
   	 			  print CONF 'stop_sniff_command=' .'echo "Mode: ESS" > /proc/driver/aironet/%sniffer_device%/Config' . "\n";
		 	     # Command to swich the channel 
	    			  print CONF 'channel_switch_command=' .'echo "Channel: %channel%" > /proc/driver/aironet/%sniffer_device%/Config' . "\n";
  		}
  		elsif ($dev2typ eq 'prism2')
  		{
  			print CONF "iface2typ=prism2\n";

			  print "\nSet your wireless interface name [default: wlan1] : ";
	 		 chomp(my $sniffer_device=<STDIN>);
  			if(!$sniffer_device) 
  			{ 
  				print CONF "sniffer_device=wlan1\n";
  			}
  			else 
  			{   print CONF "sniffer_device=$sniffer_device\n";
	  		}

  			#-- Write the default settings for bring prism cards in sniffing mode --#
        	  	# Command to bring $sniffer_device into rfmon mode
  					print CONF 'start_sniff_command=' . '/sbin/wlanctl-ng %sniffer_device% lnxreq_wlansniff channel=6 prismheader=false keepwepflags=false enable=true > /dev/null'."\n";
		   	   # Command to stop $sniffer_device from rfmon mode
   	 			  print CONF 'stop_sniff_command=' .'/sbin/wlanctl-ng %sniffer_device% lnxreq_wlansniff channel=6 enable=false > /dev/null'."\n";
		 	     # Command to swich the channel 
	    			  print CONF 'channel_switch_command=' .'/sbin/wlanctl-ng %sniffer_device% lnxreq_wlansniff channel=%channel% prismheader=false keepwepflags=false enable=true > /dev/null' . "\n";
 		 }
  		elsif ($dev2typ eq 'lucent')
  		{
  			print CONF "iface2typ=lucent\n";
			  print "\nSet your wireless interface name [default: eth2] : ";
	 		 chomp(my $sniffer_device=<STDIN>);
  			if(!$sniffer_device) 
  			{ 
  				print CONF "sniffer_device=eth2\n";
  			}
  			else 
  			{   print CONF "sniffer_device=$sniffer_device\n";
	  		}

  			#-- Write the default settings for bring prism cards in sniffing mode --#
        	  	# Command to bring $sniffer_device into rfmon mode
  					print CONF 'start_sniff_command=' . 'iwpriv %sniffer_device% monitor 2 11'."\n";
		   	   # Command to stop $sniffer_device from rfmon mode
   	 			  print CONF 'stop_sniff_command=' .'iwpriv %sniffer_device% monitor 0 11'."\n";
		 	     # Command to swich the channel 
	    			  print CONF 'channel_switch_command=' .'iwpriv %sniffer_device% monitor 2 %channel%' . "\n";
 		 }
  		else
  		{
  			print "\nSorry you entered something strange...please enter either \"cisco\" or \"prism2\"";
  			print "\nThe program cannot continue.....aborting...";
  			exit;
  		}


	  }

	#-- End of interface config, now start with path config --#
	  print CONF "mwbuttons=$buttonstobuild\n";


	  # Get the path to ifconfig
      print "\nTry to get the path to your ifconfig ......";
	  my $path_ifconfig = `which ifconfig`; 
	  $path_ifconfig =~ s/\n//g; 
	  if ($path_ifconfig)
	  {
	  	print CONF "ifpath=$path_ifconfig\n";
	  }
	  else
	  {
	  	print "\n Cannot find the path to ifconfig, set path to ifconfig [default: /sbin/ifconfig]: ";
	  	chomp($path_ifconfig=<STDIN>);
	  	if(!$path_ifconfig) { print CONF "ifpath=/sbin/ifconfig\n"; }
	  	else { print CONF "ifpath=$path_ifconfig\n"; }
	  }

	  # Get the path to iwconfig
  	print "\nTry to get the path to iwconfig now .......";
	  my $path = `which iwconfig`; 
	  $path =~ s/\n//g; 
	  if ($path)
	  {
		  print CONF "iwpath=$path\n";	  		
	  }
	  else
	  {
	  	print "\n Cannot find the path to ifconfig, set path to iwconfig [default: /sbin/iwconfig]: ";
		  chomp($path=<STDIN>);
  		if(!$path) { print CONF "iwpath=/sbin/iwconfig\n"; }
  		else { print CONF "iwpath=$path\n"; }
	  }

# Do u like to enable the audio features?
  print "\n\nActivate accoustic features? [y/n] [default: y ]: ";
  chomp(my $audio=<STDIN>);
  if(!$audio || $audio eq 'y') 
  {
  	print CONF "enable_audio=1\n";
		print "\nCommand to execute when a broadcasting network is found? \ndefault [printf \"\\a\"] : ";
		chomp (my $broadfound =<STDIN>);
		if (!$broadfound || $broadfound eq 'printf "\a"' || $broadfound eq 'printf "\\a"')
		{
			print CONF "c_new_broadcast_netfound=printf \"\\a\"\n";
		}
		else
		{
			print CONF "c_new_broadcast_netfound=$broadfound\n";
		}

		print "\nCommand to execute when a NON-broadcasting network is found? \ndefault [printf \"\\a\"] : ";
		chomp (my $nbroadfound =<STDIN>);
		if (!$nbroadfound || $nbroadfound eq 'printf "\a"' || $nbroadfound eq 'printf "\\a"')
		{
			print CONF "c_new_nonbroadcast_netfound=printf \"\\a\"\n";
		}
		else
		{
			print CONF "c_new_nonbroadcast_netfound=$nbroadfound\n";
		}

		print "\nCommand to execute when a new object is found? \ndefault [printf \"\\a\"] : ";
		chomp (my $nbjfound =<STDIN>);
		if (!$nbjfound || $nbjfound eq 'printf "\a"' || $nbjfound eq 'printf "\\a"')
		{
			print CONF "c_objectfound =printf \"\\a\"\n";
		}
		else
		{
			print CONF "c_objectfound=$nbjfound\n";
		}

		
  }
  else
  {
  	print CONF "enable_audio=0\n"
  }

# Enough for now, the rest is done by hand
  print "All necessary things are now configured\n\n";
  print "\n\tYou can now run perl Wellenreiter.pl\n\n\n";
}

## Add the common stuff to configfile

sub common {

print CONF qq~

#############################################################
### You can change the following parameters if you want ####
### to change the default layout of the windows, but    ###
### it should match for anyone. If you want to be safe  ##
### leave it as it is.                                  #
########################################################

#-- Mainwindow layout --#
#How many buttons to display in a single row on the mainwindow?
columncount=1

#-- Reiceive-Statistics-Window layout --#
rxcolumn=4
rxtitle=Receive-Statistics

#-- Send-Statistics-Window layout --#
txcolumn=4
txtitle=Send-Statistics

#-- MISC-Statistics-Window layout --#
misccolumn=4
misctitle=Misc-Statistics

#-- About-Window layout --#
abouttitle=About

#-- Config-Window layout --#
configtitle=Configuration
configcolumn=4

#-- Signallevel-Window layout --#
signaltitle=Signallevel

#-- Linkquality-Window layout --#
linktitle=Linkquality

#-- Noiselevel-Window layout --#
noisetitle=Noiselevel

##########################################################
###       Don't change anything below this line       ###
########################################################

#-- General definitions --#
progname=Wellenreiter
version=v1.0

#-- Linux-wireless-extension-path  -  This should be right for all--#
wirelessfile=/proc/net/wireless

#-- Netpackets statistics file  -  This should be right for all --#
netstatsfile=/proc/net/dev

##########################################################
###             End of the config file                ###
########################################################
~;

}
# EOF #
